goog.provide('pricecheck.clickbuster');



/**
 * An array of x, y coordinates of captured touch events.
 * @type {Array.<number>}
 */
pricecheck.clickbuster.coordinates = [];


/**
 * Add a captured touch event to the coordinates array and set a timeout to
 * remove the first event coordinates after 2 seconds - i.e. after the follow up
 * click event has lapsed.
 * @param {number} x The x coordinate of the touch event.
 * @param {number} y The y coordinate of the touch event.
 */
pricecheck.clickbuster.preventGhostClick = function(x, y) {
    pricecheck.clickbuster.coordinates.push(x, y);
    window.setTimeout(pricecheck.clickbuster.pop, 2000);
};


/**
 * Remove the first two values (i.e. pair of coordinates) from the coordinates
 * array.
 */
pricecheck.clickbuster.pop = function() {
    pricecheck.clickbuster.coordinates.splice(0, 2);
};


/**
 * A click handler for busting ghost clicks. Attach this to the document.body to
 * make it a global click handler.
 *
 * Check whether a click event occurs within 25px of any captured touch events.
 * If it is, it's almost certainly the "follow up" click to our captured touch
 * event so we prevent it's default behaviour and propagation.
 * @param {goog.events.BrowserEvent} e The click event.
 */
pricecheck.clickbuster.onClick = function(e) {
    // alert('click detected');
    for (var i = 0; i < pricecheck.clickbuster.coordinates.length; i += 2) {
        var x = pricecheck.clickbuster.coordinates[i];
        var y = pricecheck.clickbuster.coordinates[i + 1];
        if (Math.abs(e.clientX - x) < 25 && Math.abs(e.clientY - y) < 25) {
            e.preventDefault();
            e.stopPropagation();
        } else {

        }
    }
};
