/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.image.image');


/**
 * Convert an image in the DOM to Base64 for data URI/offline usage. Must obey
 * SOP similar to XHR requests. However, can set Access-Control-Allow-Origin and
 * Access-Control-Allow-Credentials headers on server as workaround.
 * @param {HTMLImageElement} img The image to convert to Base64.
 * @return {string|boolean} The Base64 encoded image.
 */
pricecheck.image.image.toBase64 = function(img) {
    if (!img || typeof(img) != 'object' || typeof(img.tagName) == 'undefined') {
        return false;
    }
    if (img.tagName.toLowerCase() != 'img') {
        return false;
    }

    // Create an empty canvas element
    var canvas = document.createElement('canvas');
    if (typeof(canvas.getContext) == 'undefined') {
        return false;
    }
    canvas.width = img.width;
    canvas.height = img.height;

    // Copy the image contents to the canvas
    var ctx = canvas.getContext('2d');
    ctx.drawImage(img, 0, 0);

    // Check for cross domain security errors mentioned above.
    try {
        var data = canvas.toDataURL('image/png');
    } catch (e) {
        return false;
    }

    // Android implements toDataUrl but it is actually stubbed. Check the data
    // string to see if a valid image has been captured.
    if (data.indexOf('data:image/png') == 0) {
        return data;
    } else {
        return false;
    }
};
