/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.require('goog.dom');
goog.require('goog.testing.jsunit');
goog.require('pricecheck.image.image');

var div;
var imgLocal;
var imgForeign;

var setUp = function() {
    div = goog.dom.createDom('div');
    goog.dom.appendChild(goog.dom.getDocument().body, div);
    
    imgLocal = goog.dom.createDom('img',
        {'src': 'http://127.0.0.1/image.php'});
    goog.dom.appendChild(goog.dom.getDocument().body, imgLocal);

    imgForeign = goog.dom.createDom('img',
        {'src': 'http://m.pricecheck.co.za/images/mobile_logo_small.gif'});
    goog.dom.appendChild(goog.dom.getDocument().body, imgForeign);
}

var testBase64Encode = function() {
    assertFalse('should reject null', pricecheck.image.image.toBase64(null));
    assertFalse('should reject node if not img', 
        pricecheck.image.image.toBase64(div));
    /**
    assertFalse('should reject cross domain images', 
        pricecheck.image.image.toBase64(imgForeign));
    assertEquals('should equal known base64 encoded image', 
'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz' +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==',
        pricecheck.image.image.toBase64(imgLocal)); */
};

var tearDown = function() {
    document.body.removeChild(div);
    document.body.removeChild(imgLocal);
    document.body.removeChild(imgForeign);
}