/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.json.json');

goog.require('goog.json');



/**
 * Serialize an object to JSON string using native functions where possible and
 * falling back to Closure methods where not.
 * @param {Object} object The object to serialize.
 * @return {?string} The serialized JSON representation.
 */
pricecheck.json.json.stringify = function(object) {
    if (!goog.isObject(object)) {
        return null;
    }

    if (goog.global['JSON']) {
        return goog.global['JSON'].stringify(object);
    } else {
        return goog.json.serialize(object);
    }
};


/**
 * Parse a JSON string to object using native function where possible and
 * falling back to Closure methods where not.
 * @param {string} str The JSON string to parse.
 * @return {?Object} The deserialized object.
 */
pricecheck.json.json.parse = function(str) {
    if (!str) {
        return null;
    }

    try {
        if (goog.global['JSON']) {
            return goog.global['JSON'].parse(str);
        } else {
            return goog.json.parse(str);
        }
    } catch (err) {
        return null;
    }
};
