/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.require('goog.testing.jsunit');
goog.require('pricecheck.json.json');

var tempJson = window.JSON;

var testStringify = function() {
    
    var a = {"Foo": "Bar"};
    var b = [{"name": "Peter"}, {"name": "Tom"}];
    
    // Only objects allowed
    assertFalse('should reject null', pricecheck.json.json.stringify(null));
    assertFalse('should reject string', 
        pricecheck.json.json.stringify('test string'));
    
    // Test stringify with JSON support
    assertEquals('should equal serialized object', '{"Foo":"Bar"}', 
        pricecheck.json.json.stringify(a));
    assertEquals('should equal serialized array', 
        '[{"name":"Peter"},{"name":"Tom"}]', pricecheck.json.json.stringify(b));
    
    // Test stringify without JSON support
    window.JSON = null;
    assertEquals('should equal serialized object', 
        '{"Foo":"Bar"}', pricecheck.json.json.stringify(a));
    assertEquals('should equal serialized array', 
        '[{"name":"Peter"},{"name":"Tom"}]', pricecheck.json.json.stringify(b));
    window.JSON = tempJson;
};

var testParse = function() {

    var a = 'test';
    var b = '{"Foo": "Bar"';
    var c = '{"Foo": "Bar"}';
    
    // Test stringify with JSON support
    assertFalse('should reject malformed string', 
        pricecheck.json.json.parse(a));
    assertFalse('should reject malformed string', 
        pricecheck.json.json.parse(b));
    assertFalse('should reject null', pricecheck.json.json.parse(null));
    assertFalse('should reject false', pricecheck.json.json.parse(false));
    assertObjectEquals('should equal object', 
        {"Foo":"Bar"}, pricecheck.json.json.parse('{"Foo": "Bar"}'));
    assertArrayEquals('should equal array', 
        [{"name":"Peter"},{"name":"Tom"}], 
        pricecheck.json.json.parse('[{"name":"Peter"},{"name":"Tom"}]'));
    
    // Test stringify without JSON support
    window.JSON = null;
    assertFalse('should reject malformed string', 
        pricecheck.json.json.parse(a));
    assertFalse('should reject malformed string', 
        pricecheck.json.json.parse(b));
    assertFalse('should reject null', pricecheck.json.json.parse(null));
    assertFalse('should reject false', pricecheck.json.json.parse(false));
    assertObjectEquals('should equal object', 
        {"Foo":"Bar"}, pricecheck.json.json.parse('{"Foo": "Bar"}'));
    assertArrayEquals('should equal array', 
        [{"name":"Peter"},{"name":"Tom"}], 
        pricecheck.json.json.parse('[{"name":"Peter"},{"name":"Tom"}]'));
    window.JSON = tempJson;
    
};
