//NB: when compiling you need to manually edit the compiled main.js file
//change barcodeScanner.<compiled variable name> to barcodeScanner.scan
//This is because the barcode class falls outside the JS getting compiled
// - riaan@platinumseed.com

/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.Main');

goog.require('goog.History');
goog.require('goog.dom');
goog.require('goog.pubsub.PubSub');
goog.require('goog.string');
goog.require('goog.style');
goog.require('goog.style.transition');
goog.require('goog.ui.Component');
goog.require('goog.userAgent');
goog.require('pricecheck.Device');
goog.require('pricecheck.clickbuster');
goog.require('pricecheck.ui.page.about.About');
goog.require('pricecheck.ui.page.about.Contact');
goog.require('pricecheck.ui.page.about.Help');
goog.require('pricecheck.ui.page.barcode.Barcode');
goog.require('pricecheck.ui.page.barcode.Scanner');
goog.require('pricecheck.ui.page.category.Category');
goog.require('pricecheck.ui.page.download.Prompt');
goog.require('pricecheck.ui.page.favorites.Favorites');
goog.require('pricecheck.ui.page.header.Header');
goog.require('pricecheck.ui.page.insurance.Intermediate');
goog.require('pricecheck.ui.page.home.Home');
goog.require('pricecheck.ui.page.menu.Menu');
goog.require('pricecheck.ui.page.offline.Offline');
goog.require('pricecheck.ui.page.product.Image');
goog.require('pricecheck.ui.page.product.Product');
goog.require('pricecheck.ui.page.products.Products');
goog.require('pricecheck.ui.page.search.Search');
goog.require('pricecheck.ui.page.shop.Contact');
goog.require('pricecheck.ui.page.shop.Reviews');
goog.require('pricecheck.ui.progress.Progress');

/**
 * @param {goog.History} history The history object used for navigation.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @extends {goog.ui.Component}
 * @constructor
 */
pricecheck.Main = function(history, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * A history object used for navigation.
     * @type {goog.History}
     * @private
     */
    this.history_ = history;

    /**
     * A history object used for navigation.
     * @type {?goog.ui.Component}
     * @private
     */
    this.header_ = null;

    /**
     * The currently rendered page component.
     * @type {?goog.ui.Component}
     * @private
     */
    this.currentPage_ = null;

    /**
     * Whether we have hsitory or not. Completely innacurate. On first load it
     * will be false, and for every request after true.
     * @type {boolean}
     * @private
     */
    this.hasHistory_ = false;

    /**
     * An Event Bus.
     * @type {goog.pubsub.PubSub}
     * @private
     */
    this.eventBus_ = goog.pubsub.PubSub.getInstance();
};
goog.inherits(pricecheck.Main, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.Main.prototype.createDom = function() {
    pricecheck.Main.superClass_.createDom.call(this);

    // Only show the Appstore download prompt under these conditions:
    // - No hide cookie is set
    // - We have an appstore link
    // - The application is not native
    var downloadPrompt = new pricecheck.ui.page.download.Prompt();
    if (!downloadPrompt.isHidden() &&
        pricecheck.device.getAppUrl() != null &
        pricecheck.device.isNative() == false) {

        //downloadPrompt.render(this.element_);
    }

    var progress = pricecheck.ui.progress.Progress.getInstance();
    progress.render();

    this.header_ = new pricecheck.ui.page.header.Header();
    this.addChild(this.header_, true);

    this.contentEl_ = goog.dom.createDom('div',
        {'id': 'content', 'class': goog.getCssName('content')}, null);
    goog.dom.appendChild(this.element_, this.contentEl_);

    pricecheck.Main.progress = goog.dom.getElement('progress');
    goog.style.setStyle(pricecheck.Main.progress, 'top',
        goog.dom.getViewportSize().height / 2 + 'px');
};


/**
 * @inheritDoc
 */
pricecheck.Main.prototype.enterDocument = function() {
    pricecheck.Main.superClass_.enterDocument.call(this);

    this.history_.setEnabled(true);

    this.getHandler()
        .listen(this.history_, goog.history.EventType.NAVIGATE, function(e) {
            e.stopPropagation();
            this.router_(e.token);
        }, false, this)
        .listen(document, 'click', pricecheck.clickbuster.onClick, true);
    this.eventBus_.subscribe('/offline', function(message) {
        this.router_('offline');
    }, this);

    this.router_(this.history_.getToken());

    // For Blackberry Phonegap applications, override back button.
    if (pricecheck.device.isNative() &&
        pricecheck.device.getOs() == pricecheck.Device.os.BLACKBERRY) {

        //blackberry.system.event.onHardwareKey(blackberry.system.event.KEY_BACK,
        //    function(e) {
        //    window['history'].back();
        //});
    }
};


/**
 * Routes, instantiates and renders pages based on the request.
 * @param {string} requestUri A request URI for routing.
 * @private
 */
pricecheck.Main.prototype.router_ = function(requestUri) {

    var gaPlugin = window['plugins']['gaPlugin'];

    // Hide address bar in Android.
    window.scrollTo(0, 1);

    this.header_.reset();

    if (!this.hasHistory_) {
        this.header_.showBackButton(false);
    }
    this.hasHistory_ = true;

    var request = (requestUri.indexOf('/') > -1) ? requestUri.split('/') :
        [requestUri];

    var component;

    // Track page
    if(document.getElementById('body').className.match(new RegExp('(\\s|^)device-active(\\s|$)')))
    {
        $log_url                = '/' + request[0];

        // Check for appended values to the URI
        if(typeof request[1] != 'undefined')
        {
            $log_url            += '/' + request[1];
        }
        gaPlugin.trackPage(nativePluginResultHandler, nativePluginErrorHandler, $log_url);
    };

    // Route
    switch (request[0]) {
        case 'menu':
            component = new pricecheck.ui.page.menu.Menu();
            this.header_.showSearchButton(false);
            this.header_.showSearch(true);
            break;
        case 'category':
            component = new pricecheck.ui.page.category.Category(
                parseInt(request[1], 10));
            break;
        case 'product':
            component = new pricecheck.ui.page.product.Product(
                parseInt(request[1], 10));
            break;
        case 'image':
            component = new pricecheck.ui.page.product.Image(request[1]);
            break;
        case 'products':
            component = new pricecheck.ui.page.products.Products(
                parseInt(request[1], 10));
            break;
        case 'favorites':
            component = new pricecheck.ui.page.favorites.Favorites();
            break;
        case 'search':
            component = new pricecheck.ui.page.search.Search(request[1]);
            this.header_.setSearchText(goog.string.urlDecode(request[1]));
            this.header_.showSearch(true);
            break;
        case 'barcode':
            if(goog.isDef(window['plugins']['barcodeScanner'])) 
            {	
                if(pricecheck.device.isBB6() == true)
                {
                    component = new pricecheck.ui.page.barcode.Barcode();
                }
                else if(device.platform == 'blackberry10')
                {
                    component = new pricecheck.ui.page.barcode.Barcode();
                }
                else
                {
                    component = new pricecheck.ui.page.barcode.Scanner();
                }
            } 
			else
            {	
                component = new pricecheck.ui.page.barcode.Barcode();
            }
            break;
        case 'barcode_manual':
            component = new pricecheck.ui.page.barcode.Barcode();
            break;
        case 'shop':
            component = new pricecheck.ui.page.shop.Reviews(request[1]);
            break;
        case 'shop_contact':
            component = new pricecheck.ui.page.shop.Contact(request[1]);
            break;
        case 'about':
            component = new pricecheck.ui.page.about.About();
            break;
        case 'insurance':
            component = new pricecheck.ui.page.insurance.Intermediate();
            break;
        case 'contact':
            component = new pricecheck.ui.page.about.Contact();
            break;
        case 'help':
            component = new pricecheck.ui.page.about.Help();
            break;
        case 'offline':
            component = new pricecheck.ui.page.offline.Offline();
            break;
        default:
            component = new pricecheck.ui.page.home.Home();
            this.header_.showSearchButton(false);
            this.header_.showSearch(true);
            break;
    }

    if (this.currentPage_) {
        this.currentPage_.dispose();
    }

    if (component) {
        this.currentPage_ = component;
        this.currentPage_.render(this.contentEl_);

        if (typeof(window['_gaq']) != 'undefined') {
            window['_gaq'].push(['_trackPageview', requestUri]);
        }
    }

    // Hide address bar in Android.
    window.scrollTo(0, 1);

    // For Blackberry, try and force reflow.
    if (pricecheck.device.getOs() == pricecheck.Device.os.BLACKBERRY) {
        goog.style.setHeight(this.contentEl_, 0);
        goog.style.setHeight(this.contentEl_, 'auto');
    }
};


/**
 * Determine whether the user is online or not.
 * @return {boolean} Whether the user is online or not.
 */
pricecheck.isOnLine = function() {
	
    if(!goog.isDef(window['navigator'])){
		
        return true;
    }
    if(goog.isDef(window['navigator']['network'])){
		
        if(goog.isDef(window['navigator']['network']['connection'])
            && window['navigator']['network']['connection']['type'] == 'none'){
				
            return false;	
        }
		else{
            return true;
        }
    } 
	else if(goog.isDef(window['navigator']['onLine'])){
		
        if(window.navigator.onLine === false){
				
            return false;
        }
		else{
            return true;
        }
    }
    return true;
};


/**
 * Details about the current device.
 * @type {pricecheck.Device}
 */
pricecheck.device = new pricecheck.Device();


/**
 * Init and launch the application.
 * @param {string} host The fully qualified host the application is running
 *     from. Used when proxying to allow cross-domain XHR requests.
 * @param {string} apiHost The fully-qualified host of the API.
 */
pricecheck.init = function(host, apiHost) {

    pricecheck.HOST = host;
    pricecheck.API_HOST = apiHost;

    goog.addSingletonGetter(goog.pubsub.PubSub);

    // Add South African currency code
    goog.i18n.currency.CurrencyInfo['ZAR'] = [2, 'R', 'ZAR'];
    // Set up currency formatter
    var currency = 'ZAR';
    pricecheck.currency = new goog.i18n.NumberFormat(
        goog.i18n.NumberFormat.Format.CURRENCY, currency);

    var main = new pricecheck.Main(new goog.History());
    main.render(goog.dom.getElement('main'));
};


goog.exportSymbol('pricecheck.init', pricecheck.init);
