/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.dialog.ButtonSet');

goog.require('goog.ui.Dialog.ButtonSet');



/**
 * A button set defines the behaviour of a set of buttons that the dialog can
 * show.  Uses the {@link goog.structs.Map} interface.
 * @param {goog.dom.DomHelper=} opt_domHelper Optional DOM helper; see {@link
 *    goog.ui.Component} for semantics.
 * @constructor
 * @extends {goog.ui.Dialog.ButtonSet}
 */
pricecheck.ui.dialog.ButtonSet = function(opt_domHelper) {
    goog.ui.Dialog.ButtonSet.call(this, opt_domHelper);

};
goog.inherits(pricecheck.ui.dialog.ButtonSet, goog.ui.Dialog.ButtonSet);


/**
 * A CSS className to use for buttons.
 * @type {string}
 * @private
 */
pricecheck.ui.dialog.ButtonSet.prototype.class_ =
    goog.getCssName('modal-button') + ' ' +
    goog.getCssName('gradient-grey-twotone') + ' ' +
    goog.getCssName('button-grey') + ' ' +
    goog.getCssName('goog-buttonset');


/**
 * @inheritDoc
 */
pricecheck.ui.dialog.ButtonSet.prototype.render = function() {
    if (this.element_) {
        this.element_.innerHTML = '';
        var domHelper = goog.dom.getDomHelper(this.element_);
        goog.structs.forEach(this, function(caption, key) {
            var button = domHelper.createDom('button', {'name': key}, caption);
            button.className = this.class_;
            if (key == this.defaultButton_) {
                button.className += goog.getCssName('modal-button-default');
            }
            this.element_.appendChild(button);
        }, this);
    }
};


/**
 * Creates a new ButtonSet with a single 'Cancel' button, which is set with
 * cancel button semantics so that pressing escape will close the dialog.
 * @return {!goog.ui.Dialog.ButtonSet} The created ButtonSet.
 */
pricecheck.ui.dialog.ButtonSet.createCancel = function() {
    return new pricecheck.ui.dialog.ButtonSet().
        addButton(goog.ui.Dialog.ButtonSet.DefaultButtons.CANCEL, true, true);
};


/**
 * Creates a new ButtonSet with a 'Send' and 'Cancel' button, which is set with
 * cancel button semantics so that pressing escape will close the dialog.
 * @return {!goog.ui.Dialog.ButtonSet} The created ButtonSet.
 */
pricecheck.ui.dialog.ButtonSet.createSendCancel = function() {
    return new pricecheck.ui.dialog.ButtonSet()
        .addButton({
            key: goog.ui.Dialog.DefaultButtonKeys.OK,
            caption: 'Send'
        }, true, false)
        .addButton(goog.ui.Dialog.ButtonSet.DefaultButtons.CANCEL, true, true);
};
