/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.dialog.share.Email');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.dom.dataset');
goog.require('goog.dom.forms');
goog.require('goog.format.EmailAddress');
goog.require('goog.string');
goog.require('goog.window');

goog.require('pricecheck.net.Xhr');
goog.require('pricecheck.ui.dialog.ButtonSet');
goog.require('pricecheck.ui.dialog.Dialog');
goog.require('pricecheck.ui.dialog.email.template');



/**
 *
 * @param {Object} product The XHR response object.
 * @param {string} link The link to the product.
 * @extends {pricecheck.ui.dialog.Dialog}
 * @constructor
 */
pricecheck.ui.dialog.share.Email = function(product, link) {
    pricecheck.ui.dialog.Dialog.call(this);

    /**
     * The XHR response object.
     * @type {Object?}
     * @private
     */
    this.product_ = product;

    /**
     * The link to the product.
     * @type {string}
     * @private
     */
    this.link_ = link;

    this.setTitle('Share via email:');
    this.setDraggable(false);
    this.setButtonSet(pricecheck.ui.dialog.ButtonSet.createSendCancel());
    this.setDisposeOnHide(true);
    this.setContent(pricecheck.ui.dialog.email.template.Email());

};
goog.inherits(pricecheck.ui.dialog.share.Email, pricecheck.ui.dialog.Dialog);


/**
 * @inheritDoc
 */
pricecheck.ui.dialog.share.Email.prototype.enterDocument = function() {
    pricecheck.ui.dialog.share.Email.superClass_.enterDocument.call(this);

    var emailEl = goog.dom.getElementByClass(goog.getCssName('email'),
        this.element_);
    var messageEl = goog.dom.getElementByClass(goog.getCssName('message'),
        this.element_);

    this.reposition();

    this.getHandler().listen(this, goog.ui.Dialog.EventType.SELECT,
        function(e) {

        var errorEl;

        if (e.key == 'ok') {
            e.preventDefault();
            var email = new goog.format.EmailAddress(
                goog.dom.forms.getValue(emailEl).toString());
            if (email.isValid()) {
                this.sendEmail_(email.toString(),
                    goog.dom.forms.getValue(messageEl));
            } else {
                if (typeof errorEl == 'undefined') {
                    errorEl = goog.dom.createDom('div', {'class': 'error'});
                    goog.dom.appendChild(
                        goog.dom.getAncestorByClass(emailEl,
                            goog.getCssName('form-padding-bottom')), errorEl);
                }
                errorEl.innerHTML = 'Please enter a valid email address.';
            }
        }
    }, false, this);

};


/**
 * Send the email via the Priceheck API.
 * @param {string} email The recipient email.
 * @param {string} opt_message The optional message to send.
 * @private
 */
pricecheck.ui.dialog.share.Email.prototype.sendEmail_ = function(email, 
    opt_message) {

    var url = pricecheck.API_HOST +
        '/crud/entity/product/mail_product' +
        '?to=' + goog.string.urlEncode(email) +
        '&message=' + goog.string.urlEncode(opt_message) +
        '&link=' + goog.string.urlEncode(this.link_) +
        '&format=json&appversion=za-mtn-android-1.6.2';

    pricecheck.net.Xhr.send(
        pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url),
        null,
        goog.bind(this.setVisible, this, false),
        goog.bind(this.setVisible, this, false),
        'GET',
        false);
};
