/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.dialog.share.Share');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.dom.dataset');
goog.require('goog.dom.forms');
goog.require('goog.format.EmailAddress');
goog.require('goog.string');
goog.require('goog.structs');
goog.require('goog.ui.Dialog');
goog.require('goog.window');
goog.require('pricecheck.net.Xhr');
goog.require('pricecheck.ui.FastButton');

goog.require('pricecheck.ui.dialog.ButtonSet');
goog.require('pricecheck.ui.dialog.Dialog');
goog.require('pricecheck.ui.dialog.share.Email');
goog.require('pricecheck.ui.dialog.share.template');



/**
 * @param {Object} product The XHR response object.
 * @extends {pricecheck.ui.dialog.Dialog}
 * @constructor
 */
pricecheck.ui.dialog.share.Share = function(product) {
    pricecheck.ui.dialog.Dialog.call(this);

    /**
     * The XHR response object.
     * @type {Object?}
     * @private
     */
    this.product_ = product;

    this.setTitle('Share via:');
    this.setDraggable(false);
    this.setButtonSet(pricecheck.ui.dialog.ButtonSet.createCancel());
    this.setDisposeOnHide(true);
    this.setContent(pricecheck.ui.dialog.share.template.Share({
        link: this.getLink_()
    }));

};
goog.inherits(pricecheck.ui.dialog.share.Share, pricecheck.ui.dialog.Dialog);


/**
 * @inheritDoc
 */
pricecheck.ui.dialog.share.Share.prototype.enterDocument = function() {
    pricecheck.ui.dialog.share.Share.superClass_.enterDocument.call(this);

    var links = goog.dom.getElementsByTagNameAndClass('a', null, this.element_);
    goog.array.forEach(links, function(link) {
        this.getHandler().listen(link, 'click', function(e) {
			
			
            if (goog.dom.dataset.get(link, 'share') == 'email') {
                e.preventDefault();
                var emailDialog = new pricecheck.ui.dialog.share.Email(
                    this.product_, this.getLink_());
                emailDialog.setVisible(true);
            }
			if($(link).attr('target') == '_blank'){
				
			    e.preventDefault();
			    e.stopPropagation();
				window.open($(link).attr('href'), '_system');
			}
            this.setVisible(false);
        }, false, this);
    }, this);

};


/**
 * Returns the URL encoded link to the product on the desktop site.
 * @return {string} The URL of the product.
 * @private
 */
pricecheck.ui.dialog.share.Share.prototype.getLink_ = function() {
    return 'http://pricecheck.co.za/offers/' + this.product_['id'] + '/' +
        goog.string.urlEncode(this.product_['name']);
};
