/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.dialog.sort.Compare');
goog.provide('pricecheck.ui.dialog.sort.Event');
goog.provide('pricecheck.ui.dialog.sort.Sort');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.dom.dataset');
goog.require('goog.ui.Dialog');

goog.require('pricecheck.ui.dialog.ButtonSet');
goog.require('pricecheck.ui.dialog.Dialog');
goog.require('pricecheck.ui.dialog.sort.template');



/**
 * @param {Object} product The XHR response object.
 * @extends {pricecheck.ui.dialog.Dialog}
 * @constructor
 */
pricecheck.ui.dialog.sort.Sort = function(product) {
    pricecheck.ui.dialog.Dialog.call(this);

    /**
     * The XHR response object.
     * @type {Object?}
     * @private
     */
    this.product_ = product;

    this.setTitle('Sort by:');
    this.setDraggable(false);
    this.setButtonSet(pricecheck.ui.dialog.ButtonSet.createCancel());
    this.setDisposeOnHide(true);
    this.setContent(pricecheck.ui.dialog.sort.template.Sort());

};
goog.inherits(pricecheck.ui.dialog.sort.Sort, pricecheck.ui.dialog.Dialog);


/**
 * @inheritDoc
 */
pricecheck.ui.dialog.sort.Sort.prototype.enterDocument = function() {
    pricecheck.ui.dialog.sort.Sort.superClass_.enterDocument.call(this);

    var links = goog.dom.getElementsByTagNameAndClass('a', null, this.element_);
    goog.array.forEach(links, function(el) {
        this.getHandler().listen(el, 'click', function(e) {
            e.preventDefault();
            this.sort_(goog.dom.dataset.get(el, 'sort'));
            this.setVisible(false);
        }, false, this);
    }, this);

};


/**
 * Sort the offers by price in ascending or descending order.
 * @param {string} sort One of 'price-asc' or 'price-desc'.
 * @private
 */
pricecheck.ui.dialog.sort.Sort.prototype.sort_ = function(sort) {
    goog.array.sort(this.product_['offers'],
        pricecheck.ui.dialog.sort.Compare[sort]);
    this.dispatchEvent(pricecheck.ui.dialog.sort.Event.SORTED);
};


/**
 * An enum of sort functions.
 * @enum {function(Object, Object)}
 */
pricecheck.ui.dialog.sort.Compare = {
    'price-asc': function(a, b) {
        return parseFloat(a['price']) > parseFloat(b['price']) ? 1 :
            parseFloat(a['price']) < parseFloat(b['price']) ? -1 : 0;},
    'price-desc': function(a, b) {
        return parseFloat(a['price']) > parseFloat(b['price']) ? -1 :
            parseFloat(a['price']) < parseFloat(b['price']) ? 1 : 0;}
};


/**
 * An enum of events dispatched by the Sort component.
 * @enum {string}
 */
pricecheck.ui.dialog.sort.Event = {
    SORTED: 'offer-sorted'
};
