/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.list.ForeverList');

goog.require('goog.events.EventType');

goog.require('pricecheck.scroller.Scroller');
goog.require('pricecheck.ui.list.List');



/**
 * A forever list component. The list will automatically fetch more data and
 * append it to itself when a user reaches the end.
 *
 * @param {pricecheck.scroller.Scroller} opt_scroller An optional scroller
 *     helper.
 * @param {goog.dom.DomHelper=} opt_domHelper Optional DOM helper.
 * @extends {pricecheck.ui.list.List}
 * @constructor
 */
pricecheck.ui.list.ForeverList = function(opt_scroller, opt_domHelper) {
    pricecheck.ui.list.List.call(this, opt_domHelper);

    /**
     * The scroller helper.
     * @type {pricecheck.scroller.Scroller}
     * @private
     */
    this.scroller_ = opt_scroller || new pricecheck.scroller.Scroller();
};
goog.inherits(pricecheck.ui.list.ForeverList, pricecheck.ui.list.List);


/**
 * @inheritDoc
 */
pricecheck.ui.list.ForeverList.prototype.enterDocument = function() {
    pricecheck.ui.list.ForeverList.superClass_.enterDocument.call(this);

    this.getHandler().listen(this.scroller_,
        pricecheck.scroller.Scroller.Event.STOP, this.onScroll_);
    this.scroller_.start();
};


/**
 * @inheritDoc
 */
pricecheck.ui.list.ForeverList.prototype.disposeInternal = function() {
    pricecheck.ui.list.ForeverList.superClass_.disposeInternal.call(this);

    this.scroller_.dispose();
};


/**
 * @inheritDoc
 */
pricecheck.ui.list.ForeverList.prototype.appendItems = function(items) {
    pricecheck.ui.list.ForeverList.superClass_.appendItems.call(this, items);

    goog.dom.appendChild(this.element_, this.loadingEl_);

    if (items.length < this.itemsPerPage_) {
        this.stop();
    }
};


/**
 * Stop the list from generating more results - usually called when you have
 * reached the end of your dataset and you have nothing left to load.
 */
pricecheck.ui.list.ForeverList.prototype.stop = function() {
    goog.dom.removeNode(this.loadingEl_);
    this.scroller_.stop();
    this.getHandler().unlisten(this.scroller_,
        pricecheck.scroller.Scroller.Event.STOP, this.onScroll_);

    var backLink = goog.dom.createDom('div', {'class':
        goog.getCssName('list-back')},
        goog.dom.createDom('a', {
            'href': 'javascript:history.go(-1)',
            'class': goog.getCssName('button-header'),
            'style': 'padding: 6px 12px;'
        }, 'Back'));
    goog.dom.appendChild(this.element_, backLink);
};


/**
 * Handler for the scroll event. If we detect that user has reached the bottom
 * of the list, we invoked the XHR to fetch more results.
 * @param {goog.events.BrowserEvent} e The browser event.
 * @private
 */
pricecheck.ui.list.ForeverList.prototype.onScroll_ = function(e) {

    var documentHeight = this.getDomHelper().getDocumentHeight();
    var viewportHeight = this.getDomHelper().getViewportSize()['height'];
    var scrollbarHeight = this.getDomHelper().getDocumentScroll()['y'];
    if (viewportHeight + scrollbarHeight >= documentHeight - 140) {
        this.fetch();
    }
};
