/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.livetiles.Tile');

goog.require('goog.dom');
goog.require('goog.dom.classes');
goog.require('goog.fx.css3.Transition');
goog.require('goog.style');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.livetiles.template');



/**
 * @param {Object} tile The tile data.
 * @param {number} size The height and width of the tile.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.livetiles.Tile = function(tile, size, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The tile data
     * @type {Object}
     * @private
     */
    this.tile_ = tile;

    /**
     * The height and width of the tile.
     * @type {number}
     * @private
     */
    this.tileSize_ = size;

    /**
     * Whether the tile is currently flipped or not.
     * @type {boolean}
     * @private
     */
    this.flipped_ = false;
};
goog.inherits(pricecheck.ui.livetiles.Tile, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.livetiles.Tile.prototype.createDom = function() {
    pricecheck.ui.livetiles.Tile.superClass_.createDom.call(this);

    goog.dom.classes.add(this.element_, goog.getCssName('tile-container'));
    goog.dom.appendChild(this.element_, soy.renderAsElement(
        pricecheck.ui.livetiles.template.tile, {
            tile: this.tile_,
            size: this.tileSize_}));
};


/**
 * @inheritDoc
 */
pricecheck.ui.livetiles.Tile.prototype.enterDocument = function() {
    pricecheck.ui.livetiles.Tile.superClass_.enterDocument.call(this);

    this.tileEl_ = goog.dom.getElementByClass('tiles-container', this.element_);

};


/**
 * Toggle the flipped state of the tile.
 */
pricecheck.ui.livetiles.Tile.prototype.flip = function() {
    if (this.flipped_) {
        var transition = new goog.fx.css3.Transition(this.tileEl_, 0.5,
            null, {'top': '0'}, {
                property: 'all',
                duration: 0.5,
                timing: 'linear',
                delay: 0
        });
        transition.play();
    } else {
        var transition = new goog.fx.css3.Transition(this.tileEl_, 0.5,
            {'top': '0px'}, {'top': -this.tileSize_ + 'px'}, {
                property: 'all',
                duration: 0.5,
                timing: 'linear',
                delay: 0
            });
        transition.play();
    }
    this.flipped_ = !this.flipped_;
};
