/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.about.About');

goog.require('goog.dom');
goog.require('goog.dom.classes');
goog.require('goog.ui.Component');
goog.require('goog.ui.Zippy');

goog.require('pricecheck.net.Xhr');
goog.require('pricecheck.ui.page.about.template');



/**
 * About page component.
 *
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.about.About = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * An array of zippy's that have been created on the page.
     * @type {Array.<goog.ui.Zippy>}
     * @private
     */
    this.zippys_ = [];

    /**
     * The currently expanded zippy.
     * @type {?goog.ui.Zippy}
     * @private
     */
    this.expandedZippy_ = null;

};
goog.inherits(pricecheck.ui.page.about.About, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.about.About.prototype.createDom = function() {
    pricecheck.ui.page.about.About.superClass_.createDom.call(this);

    var headerEl = goog.dom.createDom('h1', {'class':
        goog.getCssName('border-bottom')}, 'About');
    goog.dom.appendChild(this.element_, headerEl);

    goog.dom.appendChild(this.element_,
        goog.soy.renderAsElement(pricecheck.ui.page.about.template.About, {}));

    var url = pricecheck.HOST + '/data/about.json';
    pricecheck.net.Xhr.send(
        url,
        null,
        goog.bind(this.onFetchSuccess, this),
        null,
        'GET',
        true);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.about.About.prototype.disposeInternal = function() {
    goog.structs.forEach(this.zippys_, function(zippy) {
        zippy.dispose();
    }, this);
    pricecheck.ui.page.about.About.superClass_.disposeInternal.call(this);
};


/**
 * The about content XHR success callback.
 * @param {String} response The XHR response HTML string.
 * @protected
 */
pricecheck.ui.page.about.About.prototype.onFetchSuccess = function(response) {

    goog.structs.forEach(response, function(section) {
        var header = soy.renderAsElement(
            pricecheck.ui.page.about.template.ListItem, {
                name: section['header'],
                link: section['link']
            });
        goog.dom.appendChild(this.element_, header);

        if (section['content']) {
            var content = goog.dom.createDom('div', {'class':
                goog.getCssName('help-content')});
            goog.dom.appendChild(this.element_, content);
            content.innerHTML = section['content'];

            var zippy = new goog.ui.Zippy(header, content);
            this.zippys_.push(zippy);

            this.getHandler().listen(zippy, goog.ui.Zippy.Events.ACTION,
            this.onZippyExpand_);
        }
    }, this);
	
	$('#content a').on('click', function(e){
		
		if($(this).attr('href') != undefined){

			if($(this).attr('href').substr(0,1) != "#"){
			    e.preventDefault();
			    e.stopPropagation();
				window.open($(this).attr('href'), '_system');
			}
		}
	});
};


/**
 * The callback for Zippy actions events.
 * @param {goog.events.Event} e The dispatched action event.
 * @private
 */
pricecheck.ui.page.about.About.prototype.onZippyExpand_ = function(e) {
	
    if (this.expandedZippy_) {
        this.expandedZippy_.collapse();
    }
    if (e.currentTarget.isExpanded()) {
        this.expandedZippy_ = /** @type {goog.ui.Zippy} */ (e.currentTarget);
    } else {
        this.expandedZippy_ = null;
    }
};
