/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.about.Contact');

goog.require('goog.dom');
goog.require('goog.dom.classes');
goog.require('goog.ui.Component');
goog.require('pricecheck.net.Xhr');
goog.require('pricecheck.ui.list.List');
goog.require('pricecheck.ui.page.about.template');
goog.require('pricecheck.ui.page.list.LinkRenderer');



/**
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.about.Contact = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);


};
goog.inherits(pricecheck.ui.page.about.Contact, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.about.Contact.prototype.createDom = function() {
    pricecheck.ui.page.about.Contact.superClass_.createDom.call(this);

    var headerEl = goog.dom.createDom('h1', {'class':
        goog.getCssName('border-bottom')}, 'Contact');
    goog.dom.appendChild(this.element_, headerEl);

    var contentEl = goog.dom.createDom('div', {'class':
        goog.getCssName('about-content')});
    this.innerEl_ = goog.dom.createDom('div', {'class':
        goog.getCssName('margin-inner')});
    goog.dom.appendChild(contentEl, this.innerEl_);
    goog.dom.appendChild(this.element_, contentEl);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.about.Contact.prototype.enterDocument = function() {
    pricecheck.ui.page.about.Contact.superClass_.enterDocument.call(this);

    var url = pricecheck.HOST + '/data/contact.html';
    pricecheck.net.Xhr.send(
        url,
        null,
        goog.bind(this.onFetchSuccess, this),
        null,
        'GET',
        true,
        false);
};


/**
 * The XHR success callback.
 * @param {string} response The HTML response.
 * @protected
 */
pricecheck.ui.page.about.Contact.prototype.onFetchSuccess = function(response) {
    this.innerEl_.innerHTML = response;

    var buttonEl = goog.dom.getElementsByTagNameAndClass('button', null,
        this.element_)[0];
    goog.dom.classes.add(buttonEl, goog.getCssName('button-red'));

    var formEl = goog.dom.getElementsByTagNameAndClass('form', null,
        this.element_)[0];

    this.getHandler().listen(formEl, 'submit', this.onFormSubmit);
};


/**
 * The form submit handler.
 * @param {goog.events.BrowserEvent} e The submit event.
 * @protected
 */
pricecheck.ui.page.about.Contact.prototype.onFormSubmit = function(e) {

    e.preventDefault();

    var errors = [];

    // Remove any existing error elements
    var errorEls = goog.dom.getElementsByClass(goog.getCssName('error'),
        this.element_);
    goog.structs.forEach(errorEls, function(el) {
        goog.dom.removeNode(el);
    });

    var nameEl = e.currentTarget['name'];
    var name = goog.dom.forms.getValue(nameEl);
    if (name.trim() == '') {
        errors.push([nameEl, 'Please enter your name']);
    }

    var emailEl = e.currentTarget['email'];
    var email = new goog.format.EmailAddress(
        goog.dom.forms.getValue(emailEl).toString());
    if (!email.isValid()) {
        errors.push([emailEl, 'Please enter a valid email']);
    }

    var messageEl = e.currentTarget['message'];
    var message = goog.dom.forms.getValue(messageEl);
    if (message.trim() == '') {
        errors.push([messageEl, 'Please enter your message']);
    }

    // Display errors if they exist
    if(errors.length > 0) {

        goog.structs.forEach(errors, function(errorArray) {
            var parent = goog.dom.getAncestorByClass(errorArray[0], 'sec');
            var el = goog.dom.createDom('div',
                {'class': goog.getCssName('error')}, errorArray[1]);
            goog.dom.appendChild(parent, el);
        }, this);
    }
    else
    {
        var url = pricecheck.API_HOST + '/utils/contact?' +
            goog.dom.forms.getFormDataString(
                /** @type {HTMLFormElement} */ (e.currentTarget)) 
            + '&appversion=za-mtn-android-1.6.2';

        pricecheck.net.Xhr.send(
            pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url),
            null,
            null,
            null,
            'GET',
            false);

        this.showSent_();
    }
};


/**
 * Show the message sent template.
 * @private
 */
pricecheck.ui.page.about.Contact.prototype.showSent_ = function() {
    this.innerEl_.innerHTML = pricecheck.ui.page.about.template.MessageSent();
};
