/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.barcode.Barcode');

goog.require('goog.ui.Component');
goog.require('goog.ui.LabelInput');

goog.require('pricecheck.ui.page.barcode.template');

/**
 * Barcode page component
 *
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.barcode.Barcode = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

};
goog.inherits(pricecheck.ui.page.barcode.Barcode, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.barcode.Barcode.prototype.createDom = function() {
    pricecheck.ui.page.barcode.Barcode.superClass_.createDom.call(this);

    var headerEl = goog.dom.createDom('h1', {'class':
        goog.getCssName('border-bottom')}, 'Scan Barcode');
    goog.dom.appendChild(this.element_, headerEl);

    goog.dom.appendChild(this.element_, soy.renderAsElement(
        pricecheck.ui.page.barcode.template.Barcode, {
            appUrl: pricecheck.device.getAppUrl(),
            isNative: pricecheck.device.isNative()
        }));

    this.searchInputEl_ = goog.dom.getElementsByTagNameAndClass('input', null,
        this.element_)[0];

    var submitEl = goog.dom.getElementsByTagNameAndClass('button', null,
        this.element_)[0];
    this.submitButton_ = new pricecheck.ui.FastButton(submitEl);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.barcode.Barcode.prototype.enterDocument = function() {
    pricecheck.ui.page.barcode.Barcode.superClass_.enterDocument.call(this);

    var label = new goog.ui.LabelInput('type barcode number here');
    label.decorate(this.searchInputEl_);

    this.getHandler().listen(this.submitButton_, 'click', function(e) {
        e.preventDefault();
        var term = this.searchInputEl_.value.trim();
        if (term != '') {
            window.location.href = '#search/' + term;
        }
    });
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.barcode.Barcode.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        this.submitButton_.dispose();
    }
    pricecheck.ui.page.barcode.Barcode.superClass_.disposeInternal.call(this);
};
