/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.category.Category');

goog.require('goog.dom');
goog.require('goog.style');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.carousel.Carousel');
goog.require('pricecheck.ui.list.List');
goog.require('pricecheck.ui.page.list.LinkRenderer');



/**
 * The "Browse" by Category component
 *
 * @param {number} parentId The parent Category Id. Defaults to 0.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.category.Category = function(parentId, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The parent Category Id.
     * @type {number}
     * @private
     */
    this.parentId_ = parentId || 0;

};
goog.inherits(pricecheck.ui.page.category.Category, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.category.Category.prototype.enterDocument = function() {
    pricecheck.ui.page.category.Category.superClass_.enterDocument.call(this);

    var url = pricecheck.API_HOST +
            '/crud/entity/category/get_children_by_category_id?id=' +
            this.parentId_ + '&format=json&appversion=za-mtn-android-1.6.2';

	// alert(pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url));

    pricecheck.net.Xhr.send(
        pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url),
        null,
        goog.bind(this.onCategorySuccess, this),
        null,
        'GET',
        true);
};


/**
 * The category XHR success callback.
 * @param {Object} response The XHR response object.
 */
pricecheck.ui.page.category.Category.prototype.onCategorySuccess =
    function(response) {

    // Header text
    if (response['results']['current']['name']) {
        var parentText = response['results']['current']['parent_name'];
        var currentText = response['results']['current']['name'];
    } else {
        parentText = null;
        currentText = 'All Categories';
    }

    // Create the header
    if (parentText) {
        var parentHeaderEl = goog.dom.createDom('h2', null, parentText);
        goog.dom.appendChild(this.element_, parentHeaderEl);
    }
    var headerEl = goog.dom.createDom('h1', {'class':
        goog.getCssName('border-bottom')}, currentText);
    goog.dom.appendChild(this.element_, headerEl);

    // Create the carousel
    if (typeof response['results']['products']['products'] != 'undefined' &&
        response['results']['products']['products'].length > 0 &&
        this.parentId_) {

        goog.dom.appendChild(this.element_, goog.dom.createDom('h3', null,
            'Popular Products'));
        var carousel = new pricecheck.ui.carousel.Carousel(
            response['results']['products']['products'],
            '#products/' + this.parentId_);
        this.addChild(carousel, true);
    }

     // Category list component
    var categoryList = new pricecheck.ui.list.List();
    categoryList.setRenderer(pricecheck.ui.page.list.LinkRenderer);
    this.addChild(categoryList, true);

    // Add category list items
    var categories = [];
    goog.structs.forEach(response['results']['children'], function(category) {
        var link = (category['has_children'] == 1) ?
            '#category/' + category['id'] :
            '#products/' + category['id'];
        var item = {text: category['name'], link: link};
        categories.push(item);
    });
    categoryList.appendItems(categories);
};
