/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.category.CategoryList');

goog.require('goog.structs');

goog.require('pricecheck.ui.list.List');



/**
 * A Category list component.
 *
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @extends {pricecheck.ui.list.List}
 * @constructor
 */
pricecheck.ui.page.category.CategoryList = function(opt_domHelper) {
    pricecheck.ui.list.List.call(this, opt_domHelper);

};
goog.inherits(pricecheck.ui.page.category.CategoryList,
    pricecheck.ui.list.List);


/**
 * @inheritDoc
 */
pricecheck.ui.page.category.CategoryList.prototype.onFetchSuccess =
    function(response) {
    pricecheck.ui.page.category.CategoryList.superClass_.onFetchSuccess.call(
        this, response);

    // Update the header
    if (response['results']['current']['name']) {
        var parentText = response['results']['current']['parent_name'];
        var currentText = response['results']['current']['name'];
    } else {
        parentText = null;
        currentText = 'All Categories';
    }
    this.getParent().setHeaderText(parentText, currentText);

    // Append the items
    var categories = [];
    goog.structs.forEach(response['results']['children'], function(category) {
        var link = (category['has_children'] == 1) ?
            '#category/' + category['id'] :
            '#products/' + category['id'];
        var item = {text: category['name'], link: link};
        categories.push(item);
    });
    this.appendItems(categories);
};
