goog.provide('pricecheck.ui.page.download.Prompt');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.dom.dataset');
goog.require('goog.net.Cookies');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.page.download.template');



/**
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.download.Prompt = function() {
    goog.ui.Component.call(this);

    /**
     * An array of fast buttons used in this component.
     * @type {Array.<pricecheck.ui.FastButton>}
     * @private
     */
    this.buttons_ = [];
};
goog.inherits(pricecheck.ui.page.download.Prompt, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.download.Prompt.prototype.createDom = function() {
    pricecheck.ui.page.download.Prompt.superClass_.createDom.call(this);

    this.setElementInternal(soy.renderAsElement(
        pricecheck.ui.page.download.template.Prompt, {
            url: pricecheck.device.getAppUrl()
        }));
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.download.Prompt.prototype.enterDocument = function() {
    pricecheck.ui.page.download.Prompt.superClass_.enterDocument.call(this);

    var buttonEls = goog.dom.getElementsByClass(
        goog.getCssName('prompt-button'), this.element_);

    goog.array.forEach(buttonEls, function(el) {
        var button = new pricecheck.ui.FastButton(el);
        this.buttons_.push(button);
        this.getHandler().listen(button, 'click', this.onClick_);
    }, this);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.download.Prompt.prototype.disposeInternal = function() {
    goog.array.forEach(this.buttons_, function(button) {
        button.dispose();
    });
    pricecheck.ui.page.download.Prompt.superClass_.disposeInternal.call(this);
};


/**
 * Whether or not the prompt should be hidden or not.
 * @return {boolean} Whether the prompt should be hidden or not.
 */
pricecheck.ui.page.download.Prompt.prototype.isHidden = function() {
    if (goog.net.cookies.get(
        pricecheck.ui.page.download.Prompt.HIDE_PROMPT_COOKIE, '0') == '0') {
        return false;
    } else {
        return true;
    }
};


/**
 * The click handler for the prompt.
 * @param {goog.events.BrowserEvent} e The click event.
 * @private
 */
pricecheck.ui.page.download.Prompt.prototype.onClick_ = function(e) {
    goog.net.cookies.set(pricecheck.ui.page.download.Prompt.HIDE_PROMPT_COOKIE,
        '1', 2592000 /* 30 days */);
    var button = /** @type {pricecheck.ui.FastButton} */ (e.target);
    var url = goog.dom.dataset.get(button.getElement(), 'url');
    if (url) {
        window.location = url;
    }
    this.dispose();
};


/**
 * @type {string} The name of the cookie that determines whether to show the
 *     download prompt or not.
 */
pricecheck.ui.page.download.Prompt.HIDE_PROMPT_COOKIE = 'hp';
