/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.favorites.Favorites');

goog.require('goog.dom');
goog.require('goog.object');
goog.require('goog.ui.Component');

goog.require('pricecheck.db.Favorites');
goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.list.List');
goog.require('pricecheck.ui.page.favorites.template');
goog.require('pricecheck.ui.page.list.ProductRenderer');



/**
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.favorites.Favorites = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The Favorites localStorage abstraction.
     * @type {pricecheck.db.Favorites}
     * @private
     */
    this.favoriteDb_ = pricecheck.db.Favorites.getInstance();

};
goog.inherits(pricecheck.ui.page.favorites.Favorites, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.favorites.Favorites.prototype.createDom = function() {
    pricecheck.ui.page.favorites.Favorites.superClass_.createDom.call(this);

    goog.dom.classes.add(this.element_, 'favorites');
    soy.renderElement(this.element_,
        pricecheck.ui.page.favorites.template.Header, {});

    var emptyEl = goog.dom.getElementsByTagNameAndClass('a', null,
        this.element_)[0];
    this.emptyButton_ = new pricecheck.ui.FastButton(emptyEl);

    this.renderItems();

};


/**
 * @inheritDoc
 */
pricecheck.ui.page.favorites.Favorites.prototype.enterDocument = function() {
    pricecheck.ui.page.favorites.Favorites.superClass_.enterDocument.call(this);

    this.getHandler().listen(this.emptyButton_, 'click', function(e) {
        e.preventDefault();
        this.favoriteDb_.clear();
        this.renderItems();
    });

};


/**
 * @inheritDoc
 */
pricecheck.ui.page.favorites.Favorites.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        this.emptyButton_.dispose();
    }
    pricecheck.ui.page.favorites.Favorites.superClass_.disposeInternal.call(
        this);
};


/**
 * Render all items in the Favorites database
 * @protected
 */
pricecheck.ui.page.favorites.Favorites.prototype.renderItems = function() {

    this.removeChildren(true);
    if (this.messageEl_) {
        goog.dom.removeNode(this.messageEl_);
    }

    var favorites = this.favoriteDb_.findAll();
    if (goog.object.getCount(favorites) > 0) {
        var results = [];
        goog.object.forEach(favorites, function(favorite) {
            goog.array.insert(results, {
                'price': favorite['price_min'],
                'id': favorite['id'],
                'name': favorite['name'],
                'imageBase64': favorite['imageBase64'],
                'num_shops': favorite['num_shops']});
        }, this);
        this.productList_ = new pricecheck.ui.list.List();
        this.productList_.setRenderer(pricecheck.ui.page.list.ProductRenderer);
        this.addChild(this.productList_, true);
        this.productList_.appendItems(results);
    } else {
        this.messageEl_ = goog.dom.createDom('div',
            {'class': goog.getCssName('padded-text')}, 'No saved Favourites.');
        goog.dom.appendChild(this.element_, this.messageEl_);
    }

};
