/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.home.Home');

goog.require('goog.dom');
goog.require('goog.structs');
goog.require('goog.structs.Map');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.livetiles.Container');
goog.require('pricecheck.ui.page.home.template');



/**
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.home.Home = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * An array of FastButtons decorated on this page so we can dispose them
     * cleanly.
     * @type Array.<pricecheck.ui.FastButton>
     * @private
     */
    this.buttons_ = [];
};
goog.inherits(pricecheck.ui.page.home.Home, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.home.Home.prototype.createDom = function() {
    pricecheck.ui.page.home.Home.superClass_.createDom.call(this);

    goog.dom.classes.add(this.element_, goog.getCssName('home'));

    this.shortcutEl_ = soy.renderAsElement(
        pricecheck.ui.page.home.template.Shortcuts, {});
    goog.dom.appendChild(this.element_, this.shortcutEl_);

    var subHeader = goog.dom.createDom('h1', {}, 'What\'s Hot');
    goog.dom.appendChild(this.element_, subHeader);

    this.tileContentEl_ = goog.dom.createDom('div',
        {'class': goog.getCssName('margin-inner'), 'style':
            'margin: 0 4px;'});
    goog.dom.appendChild(this.element_, this.tileContentEl_);

    this.tileContainer_ = new pricecheck.ui.livetiles.Container();
    this.addChild(this.tileContainer_);
    this.tileContainer_.render(this.tileContentEl_);
    this.tileContainer_.addTiles(
        pricecheck.ui.livetiles.Container.defaultTiles()
    );
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.home.Home.prototype.enterDocument = function() {
    pricecheck.ui.page.home.Home.superClass_.enterDocument.call(this);

    var linkEls = goog.dom.getElementsByClass('menu-item', this.shortcutEl_);
    goog.structs.forEach(linkEls, function(linkEl) {
        this.buttons_.push(new pricecheck.ui.FastButton(linkEl));
    }, this);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.home.Home.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        goog.structs.forEach(this.buttons_, function(button) {
            button.dispose();
        });
    }
    pricecheck.ui.page.home.Home.superClass_.disposeInternal.call(this);
};
