/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.list.LinkRenderer');

goog.require('goog.ui.Component');

goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.page.list.template');



/**
 * A link item renderer.
 *
 * @param {Object} item The link item data to render.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.list.LinkRenderer = function(item, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The link item data to render.
     * @type {Object}
     * @private
     */
    this.item_ = item;

    /**
     * The FastButton
     * @type {?pricecheck.ui.FastButton}
     * @private
     */
    this.button_ = null;

};
goog.inherits(pricecheck.ui.page.list.LinkRenderer, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.LinkRenderer.prototype.createDom = function() {

    this.setElementInternal(soy.renderAsElement(
        pricecheck.ui.page.list.template.Link, {
            text: this.item_.text,
            link: this.item_.link
        }));

    this.button_ = new pricecheck.ui.FastButton(this.element_);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.LinkRenderer.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        this.button_.dispose();
    }
    pricecheck.ui.page.list.LinkRenderer.superClass_.disposeInternal.call(this);
};
