/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.list.OfferRenderer');

goog.require('goog.dom.dataset');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.page.list.template');



/**
 * @param {Object} item The offer item to render.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.list.OfferRenderer = function(item, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The offer item to render.
     * @type {Object}
     * @private
     */
    this.item_ = item;

    /**
     * The FastButton for this element.
     * @type pricecheck.ui.FastButton
     * @private
     */
    this.button_ = null;

};
goog.inherits(pricecheck.ui.page.list.OfferRenderer, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.OfferRenderer.prototype.createDom = function() {
    pricecheck.ui.page.list.OfferRenderer.superClass_.createDom.call(this);

    this.setElementInternal(soy.renderAsElement(
        pricecheck.ui.page.list.template.Offer, {
            item: this.item_,
            price: pricecheck.currency.format(this.item_['price']),
            referrer: window.location
        }));
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.OfferRenderer.prototype.enterDocument = function() {
    pricecheck.ui.page.list.OfferRenderer.superClass_.enterDocument.call(this);

    // this.button_ = new pricecheck.ui.FastButton(this.element_);
    
    var reviewLink = goog.dom.getElementByClass(
        goog.getCssName('list-item-offer-review'), this.element_);
    var reviewButton = new pricecheck.ui.FastButton(reviewLink);
    
    this.getHandler().listen(reviewButton, 'click', function(e) {
        e.preventDefault();
        e.stopPropagation();
        window.location = goog.dom.dataset.get(e.currentTarget.getElement(),
            'link');
    });
	
	// Go back in the history
	$('.Qb-jb').on('click', function(){

		history.back();	
	});
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.OfferRenderer.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        this.button_.dispose();
    }
    pricecheck.ui.page.list.OfferRenderer.superClass_.disposeInternal.call(
        this);
};
