/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.list.ProductRenderer');

goog.require('goog.ui.Component');
goog.require('pricecheck.ui.page.list.template');



/**
 * @param {Object} item The product item to render.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.list.ProductRenderer = function(item, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The product item to render.
     * @type {Object}
     * @private
     */
    this.item_ = item;

    /**
     * The FastButton
     * @type ?pricecheck.ui.FastButton
     * @private
     */
    this.button_ = null;

};
goog.inherits(pricecheck.ui.page.list.ProductRenderer, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.ProductRenderer.prototype.createDom = function() {
    pricecheck.ui.page.list.ProductRenderer.superClass_.createDom.call(this);

    this.setElementInternal(soy.renderAsElement(
        pricecheck.ui.page.list.template.Product, {
            item: this.item_,
            price: pricecheck.currency.format(this.item_['price'])
        }));

    this.button_ = new pricecheck.ui.FastButton(this.element_);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.list.ProductRenderer.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        this.button_.dispose();
    }
    pricecheck.ui.page.list.ProductRenderer.superClass_.disposeInternal.call(
        this);
};
