/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.menu.Menu');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.dom.classes');
goog.require('goog.structs');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.FastButton');
goog.require('pricecheck.ui.page.menu.template');



/**
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.menu.Menu = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * An array of FastButtons decorated on this page so we can dispose them
     * cleanly.
     * @type Array.<pricecheck.ui.FastButton>
     * @private
     */
    this.buttons_ = [];
};
goog.inherits(pricecheck.ui.page.menu.Menu, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.menu.Menu.prototype.createDom = function() {
    pricecheck.ui.page.menu.Menu.superClass_.createDom.call(this);

    goog.dom.classes.add(this.element_, goog.getCssName('menu-container'));

    var innerEl = goog.dom.createDom('div', {'class':
        goog.getCssName('margin-inner')});
    goog.dom.appendChild(this.element_, innerEl);

    var menuItems = [
        {
            link: '#home',
            icon: goog.getCssName('icon-home'),
            text: 'Home'
        },
        {
            link: '#barcode',
            icon: goog.getCssName('icon-barcode'),
            text: 'Barcode Scanner'
        },
        {
            link: '#category',
            icon: goog.getCssName('icon-browse'),
            text: 'Browse Categories'
        },
        {
            link: '#favorites',
            icon: goog.getCssName('icon-favorites'),
            text: 'Favourites'
        },
        {
            link: '#about',
            icon: goog.getCssName('icon-about'),
            text: 'About'
        },
        {
            link: 'http://www.pricecheck.co.za/?full=1',
            icon: goog.getCssName('icon-web'),
            text: 'Full Website',
            blank: true
        }
    ];

    goog.structs.forEach(menuItems, function(menuItem) {
        var buttonEl = goog.soy.renderAsElement(
            pricecheck.ui.page.menu.template.MenuItem, {
                link: menuItem.link,
                icon: menuItem.icon,
                text: menuItem.text,
                blank: menuItem.blank || false
            });
        goog.dom.appendChild(innerEl, buttonEl);
        this.buttons_.push(new pricecheck.ui.FastButton(buttonEl));
    }, this);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.menu.Menu.prototype.disposeInternal = function() {
    if (this.isInDocument()) {
        goog.structs.forEach(this.buttons_, function(button) {
            button.dispose();
        });
    }
    pricecheck.ui.page.menu.Menu.superClass_.disposeInternal.call(this);
};
