/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.product.Image');

goog.require('goog.dom');
goog.require('goog.dom.classes');
goog.require('goog.net.ImageLoader');
goog.require('goog.string');
goog.require('goog.ui.Component');



/**
 * @param {string} imagePath The path of the image to display.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.product.Image = function(imagePath, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    this.imagePath_ = goog.string.urlDecode(imagePath);
};
goog.inherits(pricecheck.ui.page.product.Image, goog.ui.Component);


/**
 * An Image Loader utility.
 * @type {goog.net.ImageLoader}
 * @private
 */
pricecheck.ui.page.product.Image.prototype.imageLoader_;


/**
 * @inheritDoc
 */
pricecheck.ui.page.product.Image.prototype.createDom = function() {
    pricecheck.ui.page.product.Image.superClass_.createDom.call(this);

    goog.dom.classes.add(this.element_, goog.getCssName('product-image'));

    // TODO: Add product name as heading?

    pricecheck.ui.progress.Progress.getInstance().setVisible(true);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.product.Image.prototype.enterDocument = function() {
    pricecheck.ui.page.product.Image.superClass_.enterDocument.call(this);

    this.imageLoader_ = new goog.net.ImageLoader();
    this.imageLoader_.addImage('p', this.imagePath_);

    this.getHandler().listen(this.imageLoader_, goog.events.EventType.LOAD, function(e) {
        goog.dom.appendChild(this.element_, e.target);
        pricecheck.ui.progress.Progress.getInstance().setVisible(false);
    }, false, this);

    this.imageLoader_.start();
};
