/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.product.tabs.Reviews');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.list.List');
goog.require('pricecheck.ui.page.list.ReviewRenderer');
goog.require('pricecheck.ui.page.list.ExpertRenderer');



/**
 * @param {Object} product The XHR response object.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.product.tabs.Reviews = function(product, expert, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The product reviews list
     * @type {Object?}
     * @private
     */
    this.product_ = product;

    /**
     * The expert reviews list
     * @type {Object?}
     */
    this.expert_ = expert;

    /**
     * Are all expert reviews rendered
     * @type {boolean}
     * @private
     */
    this.isExpertRendered_ = false;

    /**
     * Show expert review button
     * @type {Object}
     */
    this.showExpertReviews_ = null;

};
goog.inherits(pricecheck.ui.page.product.tabs.Reviews, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.product.tabs.Reviews.prototype.createDom = function() {
    pricecheck.ui.page.product.tabs.Reviews.superClass_.createDom.call(this);

    if (this.expert_ != null && this.expert_.length > 0) {
        
        this.setElementInternal(soy.renderAsElement(
            pricecheck.ui.page.product.template.ExpertReview,
            {item: this.expert_[0]}));

        this.showExpertReviews_ = goog.dom.getElementByClass(
            goog.getCssName('expert-button'), this.element_);

        this.getHandler()
            .listen(this.showExpertReviews_, 'click', function(e) {
                e.preventDefault();
                this.expandExpertReviews_();
            });
    }

    if (this.product_['reviews'].length > 0) {
        var reviewList = new pricecheck.ui.list.List();
        reviewList.setRenderer(pricecheck.ui.page.list.ReviewRenderer);
        this.addChild(reviewList, true);
        reviewList.appendItems(this.product_['reviews']);
    } else {
         goog.dom.appendChild(this.element_, goog.dom.createDom('div',
            {'class': goog.getCssName('padded-text')},
            'There are no reviews for this shop yet.'));
    }
};

/**
 * @private
 */
pricecheck.ui.page.product.tabs.Reviews.prototype.expandExpertReviews_ = function() {

    if (this.expert_ != null && this.expert_.length > 1) {

        var text;
        var expertList = new pricecheck.ui.list.List();

        if (!this.ExpertRendered) {

            var expertReviews = this.expert_.slice(0);
            expertReviews.shift();
            
            expertList.setRenderer(pricecheck.ui.page.list.ExpertRenderer);

            var usersEl = goog.dom.getElementByClass(
                goog.getCssName('user-reviews'));

            expertList.renderBefore(usersEl);
            expertList.appendItems(expertReviews);

            this.ExpertRendered = true;
            text = 'Hide all expert reviews';

        }
        else
        {

            var expertParentEl = goog.dom.getElementByClass(
                goog.getCssName('list-item-expert-review') );

            var expertReviewEl = goog.dom.getFirstElementChild(expertParentEl);
            goog.dom.removeNode(expertReviewEl);

            expertList.dispose();
            expertList = null;

            this.ExpertRendered = false;
            text = 'See all expert reviews';

        }

        if (pricecheck.device.getOs() == pricecheck.Device.os.BLACKBERRY) {
            goog.dom.setTextContent(this.showExpertReviews_, text);
        } else {
            goog.style.setStyle(this.showExpertReviews_, 'opacity', 0);
            var timer = new goog.Timer(100);
            this.getHandler().listen(timer, 'tick', function(e) {
                goog.dom.setTextContent(this.showExpertReviews_, text);
                goog.style.setStyle(this.showExpertReviews_, 'opacity',
                    1);
                timer.dispose();
            }, false, this);
            timer.start();
        }
        
    }

};
