/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
// TODO: Refactor. This class and category are very similar. Should inherit from
// base class.
goog.provide('pricecheck.ui.page.products.Products');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.string');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.page.list.ProductRenderer');
goog.require('pricecheck.ui.page.products.ProductsList');



/**
 * Product list by category component.
 *
 * @param {number} categoryId The category of the products to display.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.products.Products = function(categoryId, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The category of the products to display.
     * @type {number}
     * @private
     */
    this.categoryId_ = categoryId;

};
goog.inherits(pricecheck.ui.page.products.Products, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.products.Products.prototype.createDom = function() {
    pricecheck.ui.page.products.Products.superClass_.createDom.call(this);

    // Header
    this.parentHeaderEl_ = goog.dom.createDom('h2');
    goog.dom.appendChild(this.element_, this.parentHeaderEl_);
    this.headerEl_ = goog.dom.createDom('h1', {'class':
        goog.getCssName('border-bottom')});
    goog.dom.appendChild(this.element_, this.headerEl_);

    var productList = new pricecheck.ui.page.products.ProductsList();
    productList.setDynamic(true);
    productList.setUrl(pricecheck.API_HOST +
        '/crud/entity/product/get_popular_by_category_id');
    productList.setParams({
        'category_id': this.categoryId_,
        'format': 'json',
        'appversion': 'za-mtn-android-1.6.2'
    });
    productList.setRenderer(pricecheck.ui.page.list.ProductRenderer);
    this.addChild(productList, true);
};


/**
 * @inheritDoc
 */
pricecheck.ui.page.products.Products.prototype.enterDocument = function() {
    pricecheck.ui.page.products.Products.superClass_.enterDocument.call(this);

};


/**
 * Set the header text for the component.
 * @param {?string} parentText The text for the parent header element.
 * @param {string} currentText The text for the current header element.
 */
pricecheck.ui.page.products.Products.prototype.setHeaderText =
    function(parentText, currentText) {

    if (this.parentHeaderEl_ && typeof(parentText) == 'string') {
         goog.dom.setTextContent(this.parentHeaderEl_, parentText);
    } else {
        goog.style.showElement(this.parentHeaderEl_, false);
    }
    if (this.headerEl_ && typeof(currentText) == 'string') {
         goog.dom.setTextContent(this.headerEl_, currentText);
    }
};
