/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.search.Search');

goog.require('goog.array');
goog.require('goog.dom');
goog.require('goog.string');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.page.list.ProductRenderer');
goog.require('pricecheck.ui.page.search.SearchList');

/**
 * Search results component.
 *
 * @param {string} term The search term.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.search.Search = function(term, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The search term.
     * @type {string}
     * @private
     */
    this.term_ = goog.string.urlDecode(term);

};
goog.inherits(pricecheck.ui.page.search.Search, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.search.Search.prototype.createDom = function() {
    pricecheck.ui.page.search.Search.superClass_.createDom.call(this);

    // Header
    var header = goog.dom.createDom('h1',
        {'class': goog.getCssName('border-bottom')},
        'Results for "' + this.term_ + '"');
    goog.dom.appendChild(this.element_, header);

    // Determine if barcode or not
    var isBarcode;
    var barcodeRegExp = /^\d{8}/;
    if (barcodeRegExp.exec(this.term_) != null) {
        isBarcode = true;
    } else {
        isBarcode = false;
    }

    // List component
    var searchList = new pricecheck.ui.page.search.SearchList();
    searchList.setDynamic(true);
    searchList.setUrl(pricecheck.API_HOST + '/crud/entity/product/search');
    searchList.setParams({
        'q': this.term_,
        'format': 'json',
        'barcode': isBarcode,
        'appversion': 'za-mtn-android-1.6.2'
    });
    searchList.setRenderer(pricecheck.ui.page.list.ProductRenderer);    

    this.addChild(searchList, true);
};
