/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.search.SearchList');

goog.require('goog.array');

goog.require('pricecheck.ui.list.ForeverList');
goog.require('pricecheck.ui.page.search.template');



/**
 * A Search list component.
 *
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @extends {pricecheck.ui.list.ForeverList}
 * @constructor
 */
pricecheck.ui.page.search.SearchList = function(opt_domHelper) {
    pricecheck.ui.list.ForeverList.call(this, null, opt_domHelper);

};
goog.inherits(pricecheck.ui.page.search.SearchList,
    pricecheck.ui.list.ForeverList);


/**
 * @inheritDoc
 */
pricecheck.ui.page.search.SearchList.prototype.onFetchSuccess =
    function(response) {
    pricecheck.ui.page.search.SearchList.superClass_.onFetchSuccess.call(
        this, response);

    if (response['results']['products'].length > 0) {
        this.appendItems(response['results']['products']);
    } else {
        if (this.hasChildren()) {
            // We've already rendered item(s), so just stop the forever scroll.
        } else {
            // Otherwise show empty message
            var message = '';
            var messageEl = goog.dom.createDom('div',
                {'class': goog.getCssName('padded-text')});
            goog.dom.appendChild(this.element_, messageEl);
            
            if (response['results']['message']) {
                message = goog.string.newLineToBr(
                    response['results']['message']);
            } else {
                message = pricecheck.ui.page.search.template.NotFoundBarcode(
                    {suggestions: response['results']['suggestions']});
            }
            messageEl.innerHTML = message;
        }
        this.stop();
    }
};
