/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.shop.Contact');

goog.require('goog.string.StringBuffer');
goog.require('goog.style');
goog.require('goog.ui.Component');

goog.require('pricecheck.ui.list.List');
goog.require('pricecheck.ui.page.shop.template');



/**
 * Shop detail component.
 *
 * @param {string} shopId The shop ID.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.shop.Contact = function(shopId, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The shop ID.
     * @type {number}
     * @private
     */
    this.shopId_ = parseInt(shopId, 10);
    if (!goog.isNumber(this.shopId_)) {
        throw 'Invalid Shop Id';
    }

    /**
     * The XHR response object.
     * @type {Object?}
     * @private
     */
    this.shop_ = null;

};
goog.inherits(pricecheck.ui.page.shop.Contact, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.shop.Contact.prototype.createDom = function() {
    pricecheck.ui.page.shop.Contact.superClass_.createDom.call(this);

};


/**
 * @inheritDoc
 */
pricecheck.ui.page.shop.Contact.prototype.enterDocument = function() {
    pricecheck.ui.page.shop.Contact.superClass_.enterDocument.call(this);

    var url = pricecheck.API_HOST +
        '/crud/entity/shop/get_shop_by_id?id=' +
        this.shopId_ + '&format=json&appversion=za-mtn-android-1.6.2';

    pricecheck.net.Xhr.send(
        pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url),
        null,
        goog.bind(this.onShopSuccess, this),
        null,
        'GET',
        true);
};


/**
 * The XHR success handler. Render the shop reviews.
 * @param {Object} response The XHR response.
 * @protected
 */
pricecheck.ui.page.shop.Contact.prototype.onShopSuccess = function(response) {

    this.shop_ = response['results'];

    goog.dom.appendChild(this.element_, soy.renderAsElement(
        pricecheck.ui.page.shop.template.Contact, {shop: this.shop_}));

    /*
    var mapEl = goog.dom.getElementByClass('shop-contact-map', this.element_);
    var geocoder = new google.maps.Geocoder();
    var address = new goog.string.StringBuffer(this.shop_['address1'], ',',
        this.shop_['address2'], ', ', this.shop_['address3'], ', ',
        this.shop_['town'], ', ', this.shop_['post_code']);
    geocoder.geocode({'address': address.toString()}, function(result, status) {
        if (status == google.maps.GeocoderStatus.OK) {
            // Display the map
            goog.style.showElement(mapEl, true);
            // The lat/lng location
            var location = result[0].geometry.location;
            // Create map
            var mapOptions = {
                center: location,
                zoom: 13,
                mapTypeId: google.maps.MapTypeId.ROADMAP
            };
            var map = new google.maps.Map(
                mapEl,
                mapOptions);
            // Center map and create pin
            map.setCenter(location);
            var marker = new google.maps.Marker({
                map: map,
                position: location
            });
        }
    });
    */
};
