/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.page.shop.Shop');

goog.require('goog.ui.Component');

goog.require('pricecheck.ui.page.shop.ReviewList');
goog.require('pricecheck.ui.page.shop.template');



/**
 * Shop detail component.
 *
 * @param {string} shopId The shop ID.
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.page.shop.Shop = function(shopId, opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    /**
     * The shop ID.
     * @type {number}
     * @private
     */
    this.shopId_ = parseInt(shopId, 10);
    if (!goog.isNumber(this.shopId_)) {
        throw 'Invalid Shop Id';
    }

    /**
     * The XHR response object.
     * @type {Object?}
     * @private
     */
    this.shop_ = null;

};
goog.inherits(pricecheck.ui.page.shop.Shop, goog.ui.Component);


/**
 * @inheritDoc
 */
pricecheck.ui.page.shop.Shop.prototype.createDom = function() {
    pricecheck.ui.page.shop.Shop.superClass_.createDom.call(this);

};


/**
 * @inheritDoc
 */
pricecheck.ui.page.shop.Shop.prototype.enterDocument = function() {
    pricecheck.ui.page.shop.Shop.superClass_.enterDocument.call(this);

    var url = pricecheck.API_HOST +
        '/crud/entity/shop/get_shop_by_id?id=' +
        this.shopId_ + '&format=json&appversion=za-mtn-android-1.6.2';

    pricecheck.net.Xhr.send(
        pricecheck.HOST + '/proxy.php?url=' + goog.string.urlEncode(url),
        null,
        goog.bind(this.onShopSuccess, this),
        null,
        'GET',
        true);
};


/**
 * The XHR success handler. Render the shop reviews.
 * @param {Object} response The XHR response.
 * @protected
 */
pricecheck.ui.page.shop.Shop.prototype.onShopSuccess = function(response) {

    this.shop_ = response['results'];

    // Header
    soy.renderElement(this.element_,
        pricecheck.ui.page.shop.template.Header, {
            shop: this.shop_});

    // Contact link
    goog.dom.appendChild(this.element_, goog.dom.createDom('div', {},
        goog.dom.createDom('a', {'href': '#shop_contact/' + this.shop_['id']},
            'Shop Contact Details')));

    // Review List
    if (this.shop_['reviews'].length > 0) {
        var reviewList = new pricecheck.ui.page.shop.ReviewList();
        reviewList.setRenderer(pricecheck.ui.page.list.ReviewRenderer);
        this.addChild(reviewList, true);
        reviewList.appendItems(this.shop_['reviews']);
        reviewList.setPage(1);
        reviewList.setDynamic(true);
        reviewList.setUrl(pricecheck.API_HOST +
            '/crud/entity/review/get_by_id');
        reviewList.setParams({
            'object_id': this.shop_['id'],
            'object': 's',
            'format': 'json',
            'appversion': 'za-mtn-android-1.6.2'
        });
    } else {
         goog.dom.appendChild(this.element_, goog.dom.createDom('div',
            {'class': goog.getCssName('padded-text')},
            'There are no reviews for this product yet.'));
    }
};
