/**
 * Copyright 2012 PriceCheck
 * @author Rob Hofmeyr
 */
goog.provide('pricecheck.ui.progress.Progress');

goog.require('goog.style');
goog.require('goog.ui.Component');
goog.require('pricecheck.ui.position');
goog.require('pricecheck.ui.progress.template');



/**
 * @param {goog.dom.DomHelper=} opt_domHelper The DOM helper object for the
 *     document we want to render in.
 * @constructor
 * @extends {goog.ui.Component}
 */
pricecheck.ui.progress.Progress = function(opt_domHelper) {
    goog.ui.Component.call(this, opt_domHelper);

    this.isVisible_ = false;

};
goog.inherits(pricecheck.ui.progress.Progress, goog.ui.Component);
goog.addSingletonGetter(pricecheck.ui.progress.Progress);


/**
 * @inheritDoc
 */
pricecheck.ui.progress.Progress.prototype.createDom = function() {
    pricecheck.ui.progress.Progress.superClass_.createDom.call(this);

    this.setElementInternal(soy.renderAsElement(
        pricecheck.ui.progress.template.Progress, null));
};


/**
 * @inheritDoc
 */
pricecheck.ui.progress.Progress.prototype.enterDocument = function() {
    pricecheck.ui.progress.Progress.superClass_.enterDocument.call(this);

};


/**
 * Shows or hides the component.
 *
 * @param {boolean} visible Whether to show or hide the component.
 */
pricecheck.ui.progress.Progress.prototype.setVisible = function(visible) {
    if (visible == this.isVisible_) {
        return;
    }
    // Reposition the element when showing it.
    if (visible) {
        this.reposition();
    }
    goog.style.showElement(this.getElement(), visible);
    this.isVisible_ = visible;
};


/**
 * Centers the component in the viewport, taking scrolling into account.
 */
pricecheck.ui.progress.Progress.prototype.reposition = function() {
    pricecheck.ui.position.centerElement(this.getElement());
};
